from django.conf import settings


class AppSettings:
    def get_setting(self, setting, default=None):
        return getattr(settings, 'NONSTOP_' + setting, default)

    @property
    def REMOTE_BASE_PATH(self):
        return self.get_setting('REMOTE_BASE_PATH', '/srv/soma/nonstop/')

    @property
    def LOCAL_BASE_PATH(self):
        return self.get_setting('LOCAL_BASE_PATH', '/media/nonstop/')

    @property
    def JINGLES_PREFIX(self):
        # relative to ..._BASE_PATH
        return self.get_setting('JINGLES_PREFIX', 'SPOTS')

    @property
    def PLAYER_COMMAND(self):
        return self.get_setting('PLAYER_COMMAND', 'mpv')

    @property
    def PLAYER_ARGS(self):
        return self.get_setting('PLAYER_ARGS', [])

    @property
    def ON_AIR_SWITCH_URL(self):
        return self.get_setting('ON_AIR_SWITCH_URL', None)

    @property
    def NO_REPEAT_DELAY(self):
        return self.get_setting('NO_REPEAT_DELAY', 7)

    @property
    def AUTO_SCHEDULE(self):
        return self.get_setting('AUTO_SCHEDULE', False)

    @property
    def SERVER_BIND_IFACE(self):
        return self.get_setting('SERVER_BIND_IFACE', '127.0.0.1')

    @property
    def SERVER_BIND_PORT(self):
        return self.get_setting('SERVER_BIND_PORT', 8888)

    @property
    def EXTRA_ZONES(self):
        # zone slug to list of zone slugs,
        # ex: {"le-mange-disque": ['hop-bop-and-co', 'up-beat-tempo']}
        # to get tracks from additional zones.
        return self.get_setting('EXTRA_ZONES', {})

    @property
    def FRENCH_QUOTA(self):
        # obligation de diffuser annuellement au moins 30% d'œuvres musicales de
        # langue française
        return self.get_setting('FRENCH_QUOTA', 30)

    @property
    def CFWB_QUOTA(self):
        # obligation de diffuser annuellement au moins 4,5% d'œuvres musicales
        # émanant de la Communauté française.
        return self.get_setting('CFWB_QUOTA', 4.5)


app_settings = AppSettings()
